@@ -26,6 +26,10 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */
 #ifndef _UPT_internal_h
 #define _UPT_internal_h
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <errno.h>
 #include <libunwind.h>
 #include <limits.h>
@@ -42,8 +46,6 @@ struct UPT_info
     pid_t pid;		/* the process-id of the child we're unwinding */
     struct elf_image ei;
     unw_dyn_info_t di_cache;
-    unw_word_t dyn_info_list_addr;
-    unsigned int checked_dyn_info_list_addr : 1;
 #if UNW_TARGET_IA64
     unw_dyn_info_t ktab;
 #endif
